cluster_pictures: Cluster pictures for local arithmetic data about hyperelliptic curves
=======================================================================================

Description
-----------

This package implements the machinery of cluster pictures of Maistret, Morgan,
Dokchitser and Dokchitser.


License
-------

GPLv2


Upstream Contact
----------------

- https://github.com/alexjbest/cluster-pictures
- https://github.com/passagemath/passagemath-pkg-cluster-pictures
